Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS HealthLake.

Actions, resources, and condition keys for AWS HealthLake - Service Authorization Reference

# Actions, resources, and condition keys for AWS HealthLake

AWS HealthLake (service prefix: `healthlake` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS HealthLake
- Resource types defined by AWS HealthLake
- Condition keys for AWS HealthLake

## Actions defined by AWS HealthLake

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateFHIRDatastore | Grants permission to create a datastore that can ingest and export FHIR data | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateResource | Grants permission to create resource | Write | datastore* |  |
DeleteFHIRDatastore | Grants permission to delete a datastore | Write | datastore* |  |
DeleteResource | Grants permission to delete resource | Write | datastore* |  |
DescribeFHIRDatastore | Grants permission to get the properties associated with the FHIR datastore, including the datastore ID, datastore ARN, datastore name, datastore status, created at, datastore type version, and datastore endpoint | Read | datastore* |  |
DescribeFHIRExportJob | Grants permission to display the properties of a FHIR export job, including the ID, ARN, name, and the status of the datastore | Read | datastore* |  |
DescribeFHIRImportJob | Grants permission to display the properties of a FHIR import job, including the ID, ARN, name, and the status of the datastore | Read | datastore* |  |
GetCapabilities | Grants permission to get the capabilities of a FHIR datastore | Read | datastore* |  |
ListFHIRDatastores | Grants permission to list all FHIR datastores that are in the user’s account, regardless of datastore status | List |  |  |
ListFHIRExportJobs | Grants permission to get a list of export jobs for the specified datastore | List | datastore* |  |
ListFHIRImportJobs | Grants permission to get a list of import jobs for the specified datastore | List | datastore* |  |
ListTagsForResource | Grants permission to get a list of tags for the specified datastore | Read | datastore |  |
ReadResource | Grants permission to read resource | Read | datastore* |  |
SearchEverything | Grants permission to search all resources related to a patient | Read | datastore* |  |
SearchWithGet | Grants permission to search resources with GET method | Read | datastore* |  |
SearchWithPost | Grants permission to search resources with POST method | Read | datastore* |  |
StartFHIRExportJob | Grants permission to begin a FHIR Export job | Write | datastore* |  |
StartFHIRImportJob | Grants permission to begin a FHIR Import job | Write | datastore* |  |
TagResource | Grants permission to add tags to a datastore | Tagging | datastore |  |
| aws:TagKeys aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} |
UntagResource | Grants permission to remove tags associated with a datastore | Tagging | datastore |  |
| aws:TagKeys |
UpdateResource | Grants permission to update resource | Write | datastore* |  |

## Resource types defined by AWS HealthLake

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
datastore | `arn:$ { Partition}:healthlake:$ { Region}:$ { Account}:datastore/fhir/$ { DatastoreId}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS HealthLake

AWS HealthLake defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters access by the presence of tag key-value pairs attached to the resource | String
aws:TagKeys | Filters access by the presence of tag keys in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.